@@ -57,21 +57,21 @@ Attribute        Type      Description
 
 :Parameters:
 
-    properties : dict, optional
+    properties: `dict`, optional
         Initialize a new instance with CF properties from a
         dictionary's key/value pairs.
 
-    attributes : dict, optional
+    attributes: `dict`, optional
         Provide the new instance with attributes from a dictionary's
         key/value pairs.
 
-    data : cf.Data, optional
+    data: `cf.Data`, optional
         Provide the new instance with an N-dimensional data array.
 
-    bounds : cf.Data or cf.CoordinateBounds, optional
+    bounds: `cf.Data` or `cf.CoordinateBounds`, optional
         Provide the new instance with cell bounds.
 
-    copy : bool, optional
+    copy: `bool`, optional
         If False then do not copy arguments prior to
         initialization. By default arguments are deep copied.
 
@@ -165,11 +165,11 @@ Warning: dim_name_map may be changed in place
 
 :Parameters:
 
-    dim_name_map : dict
+    dim_name_map: `dict`
 
 :Returns:
 
-    None
+    `None`
 
 :Examples:
 
@@ -208,14 +208,14 @@ Warning: dim_name_map may be changed in place
 
 :Parameters:
 
-    copy : bool, optional
+    copy: `bool`, optional
 
         If False then the *other* coordinate construct might get
         change in place.
 
 :Returns:
 
-    None
+    `None`
 
 :Examples:
 
@@ -1181,14 +1181,14 @@ Return the coordinate recast as an auxiliary coordinate.
 
 :Parameters:
 
-    copy : bool, optional
+    copy: `bool`, optional
         If False then the returned auxiliary coordinate is not
         independent. By default the returned auxiliary coordinate is
         independent.
 
 :Returns:
 
-    out : cf.AuxiliaryCoordinate
+    out: `cf.AuxiliaryCoordinate`
         The coordinate recast as an auxiliary coordinate.
 
 :Examples:
@@ -1211,14 +1211,14 @@ Return the coordinate recast as a dimension coordinate.
 
 :Parameters:
 
-    copy : bool, optional
+    copy: `bool`, optional
         If False then the returned dimension coordinate is not
         independent. By default the returned dimension coordinate is
         independent.
 
 :Returns:
 
-    out : cf.DimensionCoordinate
+    out: `cf.DimensionCoordinate`
         The coordinate recast as a dimension coordinate.
 
 :Examples:
@@ -1273,17 +1273,17 @@ interval edges.
 
 Parameters :
  
-    a_min : scalar
+    a_min: scalar
 
-    a_max : scalar
+    a_max: scalar
 
-    units : str or Units
+    units: str or Units
 
     {+i}
 
 :Returns: 
 
-    None
+    `None`
 
 :Examples:
 
@@ -1307,7 +1307,7 @@ are subsequently required.
 
 :Returns:
 
-    None
+    `None`
 
 :Examples:
 
@@ -1327,7 +1327,7 @@ Join a sequence of coordinates together.
 
 :Returns:
 
-    out : cf.{+Variable}
+    out: `cf.{+Variable}`
 
 '''      
         coord0 = coordinates[0]
@@ -1363,14 +1363,14 @@ than one element.
 
 :Parameters:
 
-    overlap : bool, optional    
+    overlap: `bool`, optional    
         If False then overlapping cell boundaries are not considered
         contiguous. By default cell boundaries are considered
         contiguous.
 
 :Returns:
 
-    out : bool
+    out: `bool`
         Whether or not the coordinate is contiguous.
 
 :Raises:
@@ -1431,7 +1431,7 @@ The Units are changed to '1' (nondimensionsal).
 
 :Returns:
 
-    out : cf.Coordinate
+    out: `cf.{+Variable}`
 
 :Examples:
 
@@ -1478,15 +1478,15 @@ Set the cyclicity of axes of the data array and bounds.
 
 :Parameters:
 
-    axes : (sequence of) int
+    axes: (sequence of) `int`
         The axes to be set. Each axis is identified by its integer
         position. By default no axes are set.
         
-    iscyclic: bool, optional
+    iscyclic: `bool`, optional
 
 :Returns:
 
-    out : list
+    out: `list`
 
 :Examples:
 
@@ -1518,7 +1518,7 @@ The Units are changed to '1' (nondimensionsal).
 
 :Returns:
 
-    out : cf.Coordinate
+    out: `cf.{+Variable}`
 
 :Examples:
 
@@ -1574,12 +1574,12 @@ Delete a CF property.
 
 :Parameters:
 
-    prop : str
+    prop: `str`
         The name of the CF property.
 
 :Returns:
 
-     None
+     `None`
 
 :Examples:
 
@@ -1629,7 +1629,7 @@ coordinate object is increasing or decreasing.
 
 :Returns:
 
-    None
+    `None`
         
 :Examples:
 
@@ -1647,17 +1647,17 @@ Return a string containing a full description of the coordinate.
 
 :Parameters:
 
-    display : bool, optional
+    display: `bool`, optional
         If False then return the description as a string. By default
         the description is printed, i.e. ``c.dump()`` is equivalent to
         ``print c.dump(display=False)``.
 
-    omit : sequence of strs
+    omit: sequence of `str`
         Omit the given CF properties from the description.
 
 :Returns:
 
-    out : None or str
+    out: `None` or `str`
         A string containing the description.
 
 :Examples:
@@ -1709,7 +1709,7 @@ Insert a size 1 axis into the data array and bounds in place.
 
 :Parameters:
 
-    position : int, optional
+    position: `int`, optional
         Specify the position amongst the data array axes where the new
         axis is to be inserted. By default the new axis is inserted at
         position 0, the slowest varying position.
@@ -1718,7 +1718,7 @@ Insert a size 1 axis into the data array and bounds in place.
 
 :Returns:
 
-    out : cf.Coordinate
+    out: `cf.{+Variable}`
 
 '''
         if (not self._hasData and
@@ -1766,7 +1766,7 @@ coordinate is 1 or 0 dimensional.
 
 :Parameters:
 
-    axes : (sequence of) int, optional
+    axes: (sequence of) `int`, optional
         Flip the dimensions whose positions are given. By default all
         dimensions are flipped.
 
@@ -1774,7 +1774,7 @@ coordinate is 1 or 0 dimensional.
 
 :Returns:
 
-    out : cf.Coordinate
+    out: `cf.{+Variable}`
 
 :Examples:
 
@@ -1830,9 +1830,9 @@ Insert cell bounds into the coordinate in-place.
 
 :Parameters:
 
-    bounds : cf.Data or cf.CoordinateBounds
+    bounds: `cf.Data` or `cf.CoordinateBounds`
 
-    copy : bool, optional
+    copy: `bool`, optional
 
 :Returns:
 
@@ -1891,15 +1891,15 @@ with the `insert_bounds` method.
 
 :Parameters:
 
-    data : cf.Data
+    data: `cf.Data`
 
-    bounds : cf.Data, optional
+    bounds: `cf.Data`, optional
 
-    copy : bool, optional
+    copy: `bool`, optional
 
 :Returns:
 
-    None
+    `None`
 
 '''
         if data is not None:
@@ -1964,7 +1964,7 @@ Set a CF property.
 
 :Parameters:
 
-    prop : str
+    prop: `str`
         The name of the CF property.
 
     value :
@@ -2013,7 +2013,7 @@ The Units are changed to '1' (nondimensionsal).
 
 :Returns:
 
-    out : cf.Coordinate
+    out: `cf.{+Variable}`
 
 :Examples:
 
@@ -2058,13 +2058,13 @@ Take the logarithm the data array and bounds element-wise.
 
 :Parameters:
 
-    base : number, optional
+    base: number, optional
     
     {+i}
 
 :Returns:
 
-    out : cf.Coordinate
+    out: `cf.{+Variable}`
 
 '''
         if i:
@@ -2089,7 +2089,7 @@ Remove size 1 dimensions from the data array and bounds in place.
 
 :Parameters:
 
-    axes : (sequence of) int, optional
+    axes: (sequence of) `int`, optional
         The size 1 axes to remove. By default, all size 1 axes are
         removed. Size 1 axes for removal may be identified by the
         integer positions of dimensions in the data array.
@@ -2098,7 +2098,7 @@ Remove size 1 dimensions from the data array and bounds in place.
 
 :Returns:
 
-    out : cf.Coordinate
+    out: `cf.{+Variable}`
 
 :Examples:
 
@@ -2126,7 +2126,7 @@ Permute the dimensions of the data array and bounds in place.
 
 :Parameters:
 
-    axes : (sequence of) int, optional
+    axes: (sequence of) `int`, optional
         The new order of the data array. By default, reverse the
         dimensions' order, otherwise the axes are permuted according
         to the values given. The values of the sequence comprise the
@@ -2137,7 +2137,7 @@ Permute the dimensions of the data array and bounds in place.
 
 :Returns:
 
-    out : cf.Coordinate
+    out: `cf.{+Variable}`
 
 :Examples:
 
@@ -2322,7 +2322,7 @@ object.
 
 :Returns:
 
-    out : bool
+    out: bool
         Whether or not the coordinate is increasing.
         
 :Examples:
@@ -2446,7 +2446,7 @@ The direction is inferred from one of, in order of precedence:
 
 :Returns:
 
-    out : bool
+    out: bool
         Whether or not the coordinate is increasing.
         
 True for dimension coordinate constructs, False otherwise.
@@ -2653,14 +2653,14 @@ Return the dimension coordinate.
 
 :Parameters:
 
-    copy : bool, optional
+    copy: `bool`, optional
         If False then the returned dimension coordinate is not
         independent. By default the returned dimension coordinate is
         independent.
 
 :Returns:
 
-    out : cf.DimensionCoordinate
+    out: `cf.DimensionCoordinate`
         The dimension coordinate.
 
 :Examples:
@@ -2699,7 +2699,7 @@ The direction is inferred from one of, in order of precedence:
 
 :Returns:
 
-    out : bool
+    out: bool
         Whether or not the coordinate is increasing.
         
 :Examples:
@@ -2725,34 +2725,157 @@ False
         return _direction
     #--- End: def
 
-    # DimensionCoordinate
+    # DimensionCoordinate method
     def get_bounds(self, create=False, insert=False, bound=None,
-                   cellsize=None, copy=True):
-        '''Get the cell bounds.
+                   cellsize=None, flt=0.5, copy=True):
+        '''Get or create the cell bounds.
     
 Either return its existing bounds or, if there are none, optionally
 create bounds based on the coordinate array values.
-    
+
 :Parameters:
 
-    create : bool, optional
+    create: `bool`, optional
         If True then create bounds if and only if the the dimension
         coordinate does not already have them. Bounds for Voronoi
-        cells are created unless *bound* is set.
+        cells are created unless *bound* or *cellsize* is set.
 
-    insert : bool, optional 
+    insert: `bool`, optional
         If True then insert the created bounds into the coordinate in
         place. By default the created bounds are not inserted. Ignored
         if *create* is not True.
 
-    bound : *optional*
-        If set to an upper or lower bound for the whole array, then
-        bounds are created which include this value and for which each
-        array element is in the centre of its bounds. By default
-        bounds for Voronoi cells are created. Ignored if *create* is
-        not True.
+    bound: optional
+        If set to a value larger (smaller) than the largest (smallest)
+        coordinate value then bounds are created which include this
+        value and for which each coordinate is in the centre of its
+        bounds. Ignored if *create* is False.
 
-    copy : bool, optional
+    cellsize: optional
+        .. versionadded:: 1.2.2
+
+        Define the exact size of each cell that is created. Created
+        cells are allowed to overlap do not have to be contigious.
+        Ignored if *create* is False. The *cellsize* parameter may be
+        one of:
+
+          * A data-like scalar (see below) that defines the cell size,
+            either in the same units as the coordinates or in the
+            units provided. Note that in this case, the position of
+            each coordinate within the its cell is controlled by the
+            *flt* parameter.
+
+              *Example:*     
+                To specify cellsizes of 10, in the same units as the
+                coordinates: ``cellsize=10``.
+    
+              *Example:*
+                To specify cellsizes of 1 day: ``cellsize=cf.Data(1,
+                'day')`` (see `cf.Data` for details).
+    
+              *Example:*
+                 For coordinates ``1, 2, 10``, setting ``cellsize=1``
+                 will result in bounds of ``(0.5, 1.5), (1.5, 2.5),
+                 (9.5, 10.5)``.
+      
+              *Example:*
+                 For coordinates ``1, 2, 10`` kilometres, setting
+                 ``cellsize=cf.Data(5000, 'm')`` will result in bounds
+                 of ``(-1.5, 3.5), (-0.5, 4.5), (7.5, 12.5)`` (see
+                 `cf.Data` for details).
+      
+              *Example:*
+                 For decreasing coordinates ``2, 0, -12`` setting,
+                 ``cellsize=2`` will result in bounds of ``(3, 1), (1,
+                 -1), (-11, -13)``.
+
+        ..
+
+          * A `cf.TimeDuration` defining the cell size. Only
+            applicable to reference time coordinates. It is possible
+            to "anchor" the cell bounds via the `cf.TimeDuration`
+            parameters. For example, to specify cell size of one
+            calendar month, starting and ending on the 15th day:
+            ``cellsize=cf.M(day=15)`` (see `cf.M` for details). Note
+            that the *flt* parameter is ignored in this case.
+      
+              *Example:*
+                 For coordinates ``1984-12-01 12:00, 1984-12-02 12:00,
+                 2000-04-15 12:00`` setting, ``cellsize=cf.D()`` will
+                 result in bounds of ``(1984-12-01, 1984-12-02),
+                 (1984-12-02, 1984-12-03), (2000-05-15, 2000-04-16)``
+                 (see `cf.D` for details).
+
+              *Example:*
+                 For coordinates ``1984-12-01, 1984-12-02,
+                 2000-04-15`` setting, ``cellsize=cf.D()`` will result
+                 in bounds of ``(1984-12-01, 1984-12-02), (1984-12-02,
+                 1984-12-03), (2000-05-15, 2000-04-16)`` (see `cf.D`
+                 for details).
+
+              *Example:*
+                 For coordinates ``1984-12-01, 1984-12-02,
+                 2000-04-15`` setting, ``cellsize=cf.D(hour=12)`` will
+                 result in bounds of ``(1984-11:30 12:00, 1984-12-01
+                 12:00), (1984-12-01 12:00, 1984-12-02 12:00),
+                 (2000-05-14 12:00, 2000-04-15 12:00)`` (see `cf.D`
+                 for details).
+
+              *Example:*
+                 For coordinates ``1984-12-16 12:00, 1985-01-16
+                 12:00`` setting, ``cellsize=cf.M()`` will result in
+                 bounds of ``(1984-12-01, 1985-01-01), (1985-01-01,
+                 1985-02-01)`` (see `cf.M` for details).
+
+              *Example:*
+                 For coordinates ``1984-12-01 12:00, 1985-01-01
+                 12:00`` setting, ``cellsize=cf.M()`` will result in
+                 bounds of ``(1984-12-01, 1985-01-01), (1985-01-01,
+                 1985-02-01)`` (see `cf.M` for details).
+
+              *Example:*
+                 For coordinates ``1984-12-01 12:00, 1985-01-01
+                 12:00`` setting, ``cellsize=cf.M(day=20)`` will
+                 result in bounds of ``(1984-11-20, 1984-12-20),
+                 (1984-12-20, 1985-01-20)`` (see `cf.M` for details).
+
+              *Example:*
+                 For coordinates ``1984-03-01, 1984-06-01`` setting,
+                 ``cellsize=cf.Y()`` will result in bounds of
+                 ``(1984-01-01, 1985-01-01), (1984-01-01,
+                 1985-01-01)`` (see `cf.Y` for details). Note that in
+                 this case each cell has the same bounds. This because
+                 ``cf.Y()`` is equivalent to ``cf.Y(month=1, day=1)``
+                 and the closest 1st January to both coordinates is
+                 1st January 1984.
+
+        {+data-like-scalar}
+ 
+    flt: `float`, optional
+        .. versionadded:: 1.2.2
+
+        When creating cells with sizes specified by the *cellsize*
+        parameter, define the fraction of the each cell which is less
+        its coordinate value. By default *flt* is 0.5, so that each
+        cell's coordinate is at its centre. Ignored if *cellsize* is
+        not set.
+
+          *Example:*
+             For coordinates ``1, 2, 10``, setting ``cellsize=1,
+             flt=0.5`` will result in bounds of ``(0.5, 1.5), (1.5,
+             2.5), (9.5, 10.5)``.
+  
+          *Example:*
+             For coordinates ``1, 2, 10``, setting ``cellsize=1,
+             flt=0.25`` will result in bounds of ``(0.75, 1.75),
+             (1.75, 2.75), (9.75, 10.75)``.
+  
+          *Example:* 
+             For decreasing coordinates ``2, 0, -12``, setting
+             ``cellsize=6, flt=0.9`` will result in bounds of ``(2.6,
+             -3.4), (0.6, -5.4), (-11.4, -17.4)``.
+
+    copy: `bool`, optional
         If False then the returned bounds are not independent of the
         existing bounds, if any, or those inserted, if *create* and
         *insert* are both True. By default the returned bounds are
@@ -2760,18 +2883,21 @@ create bounds based on the coordinate array values.
 
 :Returns:
 
-    out : cf.CoordinateBounds
+    out: `cf.CoordinateBounds`
         The existing or created bounds.
 
 :Examples:
 
 >>> c.get_bounds()
 >>> c.get_bounds(create=True)
->>> c.get_bounds(create=True, bound=60)
 >>> c.get_bounds(create=True, insert=True)
->>> c.get_bounds(create=True, bound=-9000.0, insert=True, copy=False)
+>>> c.get_bounds(copy=False)
+>>> c.get_bounds(create=True, insert=True, cellsize=cf.M())
+>>> c.get_bounds(create=True, insert=True, cellsize=1)
+>>> c.get_bounds(create=True, insert=True, cellsize=cf.Data(1, 'day'))
+>>> c.get_bounds(create=True, cellsize=10, flt=0.25)
 
-'''
+        '''
         if self._hasbounds:
             if copy:
                 return self.bounds.copy()
@@ -2786,47 +2912,77 @@ create bounds based on the coordinate array values.
         size = array.size    
 
         if cellsize is not None:
-#            if not isinstance(cellsize, TimeDuration):
-            cellsize = Data.asdata(abs(cellsize))
-            if cellsize.Units:
-                if self.Units.isreftime:
-                    if not cellsize.Units.istime:
-                        raise ValueError("q123423423jhgsjhbd jh ")
-                    cellsize.Units = Units(self.Units._utime.units)
-                else:
-                    if not cellsize.Units.equivalent(self.Units):
-                        raise ValueError("jhgsjhbd jh ")
-                    cellsize.Units = self.Units
-            cellsize = cellsize.datum()
-            
-            cellsize  = cellsize * 0.5
-            if not self.direction():
-                cellsize *= -1
-            
-            bounds = numpy_empty((size, 2), dtype=array.dtype)
-            bounds[:,0] = array - cellsize
-            bounds[:,1] = array + cellsize
+            if bound:
+                raise ValueError(
+"bound parameter can't be True when setting the cellsize parameter")
 
-#        if isinstance(cellsize, TimeDuration):
-#            pass
-#            bounds = numpy_empty((size, 2), dtype=dtype)
-#            cellsize = None
+            if not isinstance(cellsize, TimeDuration):
+                # ----------------------------------------------------
+                # Create bounds based on cell sizes defined by a
+                # data-like object
+                # 
+                # E.g. cellsize=10
+                #      cellsize=cf.Data(1, 'day')
+                # ----------------------------------------------------
+                cellsize = Data.asdata(abs(cellsize))
+                if cellsize.Units:
+                    if self.Units.isreftime:
+                        if not cellsize.Units.istime:
+                            raise ValueError("q123423423jhgsjhbd jh ")
+                        cellsize.Units = Units(self.Units._utime.units)
+                    else:
+                        if not cellsize.Units.equivalent(self.Units):
+                            raise ValueError("jhgsjhbd jh ")
+                        cellsize.Units = self.Units
+                cellsize = cellsize.datum()
+                
+                cellsize0 = cellsize * flt
+                cellsize1 = cellsize * (1 - flt)
+                if not self.direction():
+                    cellsize0, cellsize1 = -cellsize1, -cellsize0
+                
+                bounds = numpy_empty((size, 2), dtype=array.dtype)
+                bounds[:, 0] = array - cellsize0
+                bounds[:, 1] = array + cellsize1
+            else:
+                # ----------------------------------------------------
+                # Create bounds based on cell sizes defined by a
+                # TimeDuration object
+                # 
+                # E.g. cellsize=cf.s()
+                #      cellsize=cf.m()
+                #      cellsize=cf.h()
+                #      cellsize=cf.D()
+                #      cellsize=cf.M()
+                #      cellsize=cf.Y()
+                #      cellsize=cf.D(hour=12)
+                #      cellsize=cf.M(day=16)
+                #      cellsize=cf.M(2)
+                #      cellsize=cf.M(2, day=15, hour=12)
+                # ----------------------------------------------------
+                if not self.Units.isreftime:
+                    raise ValueError(
+"Can't create reference time bounds for non-reference time coordinates: {0!r}".format(
+    self.Units))
+
+                bounds = numpy_empty((size, 2), dtype=object)
+
+                cellsize_bounds = cellsize.bounds
+                calendar = getattr(self, 'calendar', None)
+                direction = bool(self.direction())
+
+                for c, b in izip(self.dtarray, bounds):
+                    b[...] = cellsize_bounds(*c.timetuple()[:6],
+                                             calendar=calendar, direction=direction)
         else:
             if bound is None:
+                # ----------------------------------------------------
                 # Creat Voronoi bounds
+                # ----------------------------------------------------
                 if size < 2:
-                    if cellsize is not None:
-                        raise ValueError(
+                    raise ValueError(
 "Can't create bounds for Voronoi cells from one value")
 
-#    
-#                    cellsize  = cellsize * 0.5
-#                    if not self.direction():
-#                        cellsize *= -1
-#       
-#                    coord = array.item(0,)
-#                    bounds_1d = [coord - cellsize, coord + cellsize]
-#                else:
                 bounds_1d = [array.item(0,)*1.5 - array.item(1,)*0.5]
                 bounds_1d.extend((array[0:-1] + array[1:])*0.5)
                 bounds_1d.append(array.item(-1,)*1.5 - array.item(-2,)*0.5)
@@ -2834,6 +2990,9 @@ create bounds based on the coordinate array values.
                 dtype = type(bounds_1d[0])
     
             else:
+                # ----------------------------------------------------
+                # Create
+                # ----------------------------------------------------
                 direction = self.direction()
                 if not direction and size > 1:
                     array = array[::-1]
@@ -2861,31 +3020,13 @@ create bounds based on the coordinate array values.
             bounds = numpy_empty((size, 2), dtype=dtype)
             bounds[:,0] = bounds_1d[:-1]
             bounds[:,1] = bounds_1d[1:]        
-         #--- End: if
-#        if cellsize is not None:
-#            cells = abs(bounds[:, 1] - bounds[:, 0])
-#            for i, (c, s) in enumerate(zip(array, cells)):
-#                if s <= cellsize:
-#                    continue
-#                if self.direction():
-#                    if c - bounds[i,0] <= cellsize:
-#                        bounds[i,1] = bounds[i,0] + cellsize
-#                    elif bounds[i,1] - c <= cellsize:
-#                        bounds[i,0] = bounds[i,1] - cellsize
-#                    else:
-#                        raise ValueError("asdasdasds8888888888888888888888")
-#                else:
-#                    if bounds[i,0] - c <= cellsize:
-#                        bounds[i,1] = bounds[i,0] - cellsize
-#                    elif c - bounds[i,1] <= cellsize:
-#                        bounds[i,0] = bounds[i,1] + cellsize
-#                    else:
-#                        raise ValueError("asdasdasds8888888888888888888888 66767")
-#        #--- End: if
+        #--- End: if
 
+        # Create coordinate bounds object
         bounds = CoordinateBounds(data=Data(bounds, self.Units), copy=False)
                            
         if insert:
+            # Insert coordinate bounds in-place
             self.insert_bounds(bounds, copy=copy)
 
         return bounds            
@@ -2896,12 +3037,14 @@ create bounds based on the coordinate array values.
 
 :Parameters:
 
-    value : data-like or None, optional
+    value: data-like or `None`, optional
         The period. The absolute value is used.
+        
+        {+data-like-scalar}
 
 :Returns:
 
-    out : cf.Data or None
+    out: `cf.Data` or `None`
         The period prior to the change, or the current period if no
         *value* was specified. In either case, None is returned if the
         period had not been set previously.
@@ -3144,14 +3287,14 @@ Return the auxiliary coordinate.
 
 :Parameters:
 
-    copy : bool, optional   
+    copy: `bool`, optional   
         If False then the returned auxiliary coordinate is not
         independent. By default the returned auxiliary coordinate is
         independent.
 
 :Returns:
 
-    out : cf.AuxiliaryCoordinate
+    out: `cf.AuxiliaryCoordinate`
         The auxiliary coordinate.
 
 :Examples:
