@@ -1,6 +1,7 @@
 import atexit
 
 from numpy import array       as numpy_array
+from numpy import bool_       as numpy_bool_
 from numpy import dtype       as numpy_dtype
 from numpy import expand_dims as numpy_expand_dims
 from numpy import ndarray     as numpy_ndarray
@@ -347,6 +348,24 @@ False
         return isinstance(self.subarray, numpy_ndarray)
     #--- End: if
 
+    # ----------------------------------------------------------------
+    # Attribute: read only
+    # ----------------------------------------------------------------
+    @property
+    def in_temporary_file(self):
+        '''True if and only if the partition's sub-array is on disk in a
+temporary file.
+
+.. seealso:: `array`, `in_memory`, `in_shared_memory`, `on_disk`, `to_disk`
+
+:Examples:
+
+>>> p.in_temporary_file
+False
+        '''
+        return isinstance(self.subarray, TempFileArray)
+    #--- End: def
+
     # ----------------------------------------------------------------
     # Attribute: read only
     # ----------------------------------------------------------------
@@ -366,7 +385,30 @@ True
 False
 
 '''
-        return not isinstance(self.subarray, numpy_ndarray) # return not self.in_memory
+        return not hasattr(self.subarray, '__array_interface__')
+#        return not isinstance(self.subarray, numpy_ndarray) # return not self.in_memory
+    #--- End: if
+
+    # ----------------------------------------------------------------
+    # Attribute: read only
+    # ----------------------------------------------------------------
+    @property
+    def in_file(self):
+        '''
+
+True if and only if the partition's sub-array is on disk as opposed to
+in memory.
+
+:Examples:
+
+>>> p.on_disk
+True
+>>> p.to_disk()
+>>> p.on_disk
+False
+
+'''
+        return self.on_disk and not self.in_temporary_file
     #--- End: if
 
     # ----------------------------------------------------------------
@@ -695,7 +737,7 @@ otherwise a memory leak could occur. For example:
                 p_data = subarray.view()
         #--- End: if
 
-        if not p_data.ndim and isinstance(p_data, numpy_number):
+        if not p_data.ndim and isinstance(p_data, (numpy_number, numpy_bool_)):
             # p_data is a numby number (like numpy.int64) which does
             # not support assignment, so convert to a numpy array.
             p_data = numpy_array(p_data)
