@@ -185,23 +185,23 @@ Attribute        Description
 
 :Parameters:
 
-    operator : str
+    operator: str
         The query operator.
 
-    value :
+    value:
         The right hand side of the query operation.
 
-    units : str or cf.Units, optional
+    units: str or cf.Units, optional
         The units of *value*. By default, the same units, if any, as
         the left hand side of the query operation are assumed.
 
-    exact : bool, optional
+    exact: bool, optional
         If False then string values are treated as a regular
         expressions as understood by the :py:obj:`re` module and are
         evaluated using the :py:obj:`re.match` method. Ignored for
         all operators except ``'eq'``, ``'ne'`` and ``'set'``.
 
-    attr : str, optional
+    attr: str, optional
         Specify an attribute name such that this attribute of the left
         hand side operand is compared, rather than the operand itself.
 
@@ -479,12 +479,12 @@ attribute is considered to be an attribute of the existing attribute.
 
 :Parameters:
 
-    attr : str
+    attr: str
         The attribute name.
 
 :Returns:
 
-    out : cf.Query
+    out: cf.Query
         The new query object.
 
 :Examples:
@@ -544,14 +544,14 @@ Return a string containing a full description of the instance.
 
 :Parameters:
 
-    display : bool, optional
+    display: bool, optional
         If False then return the description as a string. By default
         the description is printed, i.e. ``q.dump()`` is equivalent to
         ``print q.dump(display=False)``.
 
 :Returns:
 
-    out : None or str
+    out: None or str
         A string containing the description.
 
 :Examples:
@@ -623,12 +623,12 @@ is equivalent to ``q.evaluate(x)`` and ``x!=q`` is equivalent to
 
 :Parameters:
 
-    x : 
+    x: 
         The object for the left hand side operand of the query.
 
 :Returns:
 
-    out : 
+    out: 
         The result of the query. The nature of the result is dependent
         on the object type of *x*.
     
@@ -658,15 +658,15 @@ Evaluate the query operation for a given object.
 
 :Parameters:
 
-    x : object
+    x: object
         See `evaluate`.
 
-    parent_attr : tuple
+    parent_attr: tuple
        
 
 :Returns:
 
-    out : 
+    out: 
         See `evaluate`.
     
 :Examples:
@@ -822,19 +822,19 @@ than a value.
 
 :Parameters:
 
-    value : object
+    value: object
         The value which a variable is to be compared with.
 
-    units : str or cf.Units, optional
+    units: str or cf.Units, optional
         The units of *value*. By default, the same units as the
         variable being tested are assumed, if applicable.
 
-    attr : str, optional
+    attr: str, optional
         Return a query object for a variable's *attr* attribute.
 
 :Returns: 
 
-    out : cf.Query
+    out: cf.Query
         The query object.
 
 :Examples:
@@ -860,19 +860,19 @@ to a value.
 
 :Parameters:
 
-    value : object
+    value: object
         The value which a variable is to be compared with.
 
-    units : str or cf.Units, optional
+    units: str or cf.Units, optional
         The units of *value*. By default, the same units as the
         variable being tested are assumed, if applicable.
 
-    attr : str, optional
+    attr: str, optional
         Return a query object for a variable's *attr* attribute.
 
 :Returns: 
 
-    out : cf.Query
+    out: cf.Query
         The query object.
 
 :Examples:
@@ -898,19 +898,19 @@ than a value.
 
 :Parameters:
 
-    value : object
+    value: `object`
         The value which a variable is to be compared with.
 
-    units : str or cf.Units, optional
+    units: `str` or `cf.Units`, optional
         The units of *value*. By default, the same units as the
         variable being tested are assumed, if applicable.
 
-    attr : str, optional
+    attr: `str`, optional
         Return a query object for a variable's *attr* attribute.
 
 :Returns: 
 
-    out : cf.Query
+    out: `cf.Query`
         The query object.
 
 :Examples:
@@ -936,19 +936,19 @@ equal to a value.
 
 :Parameters:
 
-    value :
+    value:
         The value which a variable is to be compared with.
 
-    units : str or cf.Units, optional
+    units: `str` or cf.Units, optional
         The units of *value*. By default, the same units as the
         variable being tested are assumed, if applicable.
 
-    attr : str, optional
+    attr: `str`, optional
         Return a query object for a variable's *attr* attribute.
 
 :Returns:
 
-    out : cf.Query
+    out: `cf.Query`
         The query object.
 
 :Examples:
@@ -984,21 +984,21 @@ def eq(value, units=None, exact=True, attr=None):
     value 
         The value which a variable is to be compared with.
 
-    units : str or cf.Units, optional
+    units: `str` or `cf.Units`, optional
         The units of *value*. By default, the same units as the
         variable being tested are assumed, if applicable.
 
-    exact : bool, optional
+    exact: `bool`, optional
         If False then string values are to be treated as regular
         expressions understood by the :py:obj:`re` module and are
         evaluated using the :py:obj:`re.match` method.
 
-    attr : str, optional
+    attr: `str`, optional
         Return a query object for a variable's *attr* attribute.
 
 :Returns:
 
-    out : cf.Query
+    out: `cf.Query`
         The query object.
  
 :Examples:
@@ -1030,24 +1030,24 @@ def ne(value, units=None, exact=True, attr=None):
 
 :Parameters:
 
-    value : object
+    value: `object`
         The value which a variable is to be compared with.
 
-    units : str or cf.Units, optional
+    units: `str` or cf.Units, optional
         The units of *value*. By default, the same units as the
         variable being tested are assumed, if applicable.
 
-    exact : bool, optional
+    exact: `bool`, optional
         If False then string values are to be treated as regular
         expressions understood by the :py:obj:`re` module and are
         evaluated using the :py:obj:`re.match` method.
 
-    attr : str, optional
+    attr: `str`, optional
         Return a query object for a variable's *attr* attribute.
 
 :Returns: 
 
-    out : cf.Query
+    out: `cf.Query`
         The query object.
 
 :Examples:
@@ -1077,24 +1077,24 @@ b)``.
 
 :Parameters:
 
-    value0 : scalar object
+    value0: scalar object
          The lower bound of the range which a variable is to be
          compared with.
 
-    value1 : scalar object
+    value1: scalar object
          The upper bound of the range which a variable is to be
          compared with.
 
-    units : str or cf.Units, optional
+    units: `str` or cf.Units, optional
         If applicable, the units of *value0* and *value1*. By default,
         the same units as the variable being tested are assumed.
 
-    attr : str, optional
+    attr: `str`, optional
         Return a query object for a variable's *attr* attribute.
 
 :Returns: 
 
-    out : cf.Query
+    out: `cf.Query`
         The query object.
 
 :Examples:
@@ -1122,24 +1122,24 @@ range.
 
 :Parameters:
 
-    value0 : object
+    value0: object
          The lower bound of the range which a variable is to be
          compared with.
 
-    value1 : object
+    value1: object
          The upper bound of the range which a variable is to be
          compared with.
 
-    units : str or cf.Units, optional
+    units: `str` or cf.Units, optional
         If applicable, the units of *value0* and *value1*. By default,
         the same units as the variable being tested are assumed.
 
-    attr : str, optional
+    attr: `str`, optional
         Return a query object for a variable's *attr* attribute.
 
 :Returns: 
 
-    out : cf.Query
+    out: `cf.Query`
         The query object.
 
 :Examples:
@@ -1165,23 +1165,23 @@ member of a collection.
 
 :Parameters:
 
-    values : sequence
+    values: sequence
     
-    units : str or cf.Units, optional
+    units: `str` or cf.Units, optional
         The units of each element of *values*. By default, the same
         units as the variable being tested are assumed, if applicable.
 
-    exact : bool, optional
+    exact: `bool`, optional
         If False then string values are to be treated as regular
         expressions understood by the :py:obj:`re` module and are
         evaluated using the :py:obj:`re.match` method.
 
-    attr : str, optional
+    attr: `str`, optional
         Return a query object for a variable's *attr* attribute.
 
 :Returns: 
 
-    out : cf.Query
+    out: `cf.Query`
         The query object.
 
 :Examples:
@@ -1215,19 +1215,19 @@ variable for being equal to a value, i.e. this case is equivalent to
 
 :Parameters:
 
-    value : 
+    value: 
         The value which a variable is to be compared with.
     
-    units : str or cf.Units, optional
+    units: `str` or cf.Units, optional
         The units of each element of *values*. By default, the same
         units as the variable being tested are assumed, if applicable.
 
-    attr : str, optional
+    attr: `str`, optional
         Return a query object for a variable's *attr* attribute.
 
 :Returns: 
 
-    out : cf.Query
+    out: `cf.Query`
         The query object.
 
 :Examples:
@@ -1269,13 +1269,13 @@ is equivalent to ``cf.eq(value, attr='year')``.
 
 :Parameters:
 
-    value :   
+    value:   
        Either the value that the year is to be compared with, or a
        `cf.Query` object for testing the year.
 
 :Returns:
 
-    out : cf.Query
+    out: `cf.Query`
         The query object.
 
 :Examples:
@@ -1313,13 +1313,13 @@ equivalent to ``value.addattr('month')``. Otherwise
 
 :Parameters:
 
-    value :   
+    value:   
        Either the value that the month is to be compared with, or a
        `cf.Query` object for testing the month.
 
 :Returns:
 
-    out : cf.Query
+    out: `cf.Query`
         The query object.
 
 :Examples:
@@ -1357,13 +1357,13 @@ equivalent to ``cf.eq(value, attr='day')``.
 
 :Parameters:
 
-    value :   
+    value:   
        Either the value that the day is to be compared with, or a
        `cf.Query` object for testing the day.
 
 :Returns:
 
-    out : cf.Query
+    out: `cf.Query`
         The query object.
 
 :Examples:
@@ -1401,13 +1401,13 @@ is equivalent to ``cf.eq(value, attr='hour')``.
 
 :Parameters:
 
-    value :   
+    value:   
        Either the value that the hour is to be compared with, or a
        `cf.Query` object for testing the hour.
 
 :Returns:
 
-    out : cf.Query
+    out: `cf.Query`
         The query object.
 
 :Examples:
@@ -1447,13 +1447,13 @@ equivalent to ``value.addattr('minute')``. Otherwise
 
 :Parameters:
 
-    value :   
+    value:   
        Either the value that the minute is to be compared with, or a
        `cf.Query` object for testing the minute.
 
 :Returns:
 
-    out : cf.Query
+    out: `cf.Query`
         The query object.
 
 :Examples:
@@ -1493,13 +1493,13 @@ equivalent to ``value.addattr('second')``. Otherwise
 
 :Parameters:
 
-    value :   
+    value:   
        Either the value that the second is to be compared with, or a
        `cf.Query` object for testing the second.
 
 :Returns:
 
-    out : cf.Query
+    out: `cf.Query`
         The query object.
 
 :Examples:
@@ -1537,13 +1537,13 @@ equivalent to ``value.addattr('cellsize')`` (see
 
 :Parameters:
 
-    value :   
+    value:   
        Either the value that the cell size is to be compared with, or a
        `cf.Query` object for testing the cell size.
 
 :Returns:
 
-    out : cf.Query
+    out: `cf.Query`
         The query object.
 
 :Examples:
@@ -1587,7 +1587,7 @@ than a date-time.
 
 :Returns:
 
-    out : cf.Query
+    out: `cf.Query`
         The query object.
 
 :Examples:
@@ -1632,7 +1632,7 @@ date-time.
 
 :Returns:
 
-    out : cf.Query
+    out: `cf.Query`
         The query object.
 
 :Examples:
@@ -1677,7 +1677,7 @@ date-time.
 
 :Returns:
 
-    out : cf.Query
+    out: `cf.Query`
         The query object.
 
 :Examples:
@@ -1722,7 +1722,7 @@ date-time.
 
 :Returns:
 
-    out : cf.Query
+    out: `cf.Query`
         The query object.
 
 :Examples:
@@ -1767,7 +1767,7 @@ date-time.
 
 :Returns:
 
-    out : cf.Query
+    out: `cf.Query`
         The query object.
 
 :Examples:
@@ -1812,7 +1812,7 @@ date-time.
 
 :Returns:
 
-    out : cf.Query
+    out: `cf.Query`
         The query object.
 
 :Examples:
@@ -1855,7 +1855,7 @@ attr='lower_bounds') & cf.le(value1, attr='upper_bounds')``.
 
 :Returns:
 
-    out : cf.Query
+    out: `cf.Query`
         The query object.
 
 :Examples:
@@ -1884,7 +1884,7 @@ attr='lower_bounds') & cf.gt(value1, attr='upper_bounds')``.
 
 :Returns:
 
-    out : cf.Query
+    out: `cf.Query`
         The query object.
 
 :Examples:
@@ -1913,7 +1913,7 @@ attr='lower_bounds')``.
 
 :Returns:
 
-    out : cf.Query
+    out: `cf.Query`
         The query object.
 
 :Examples:
@@ -1941,7 +1941,7 @@ attr='lower_bounds')``.
 
 :Returns:
 
-    out : cf.Query
+    out: `cf.Query`
         The query object.
 
 :Examples:
@@ -1969,7 +1969,7 @@ attr='upper_bounds')``.
 
 :Returns:
 
-    out : cf.Query
+    out: `cf.Query`
         The query object.
 
 :Examples:
@@ -1997,7 +1997,7 @@ attr='upper_bounds')``.
 
 :Returns:
 
-    out : cf.Query
+    out: `cf.Query`
         The query object.
 
 :Examples:
@@ -2018,7 +2018,7 @@ def jja():
 
 :Returns:
 
-    out : cf.Query
+    out: `cf.Query`
         The query object.
 
 :Examples:
@@ -2045,7 +2045,7 @@ November.
 
 :Returns:
 
-    out : cf.Query
+    out: `cf.Query`
         The query object.
 
 :Examples:
@@ -2071,7 +2071,7 @@ def djf():
 
 :Returns:
 
-    out : cf.Query
+    out: `cf.Query`
         The query object.
 
 :Examples:
@@ -2098,7 +2098,7 @@ def mam():
 
 :Returns:
 
-    out : cf.Query
+    out: `cf.Query`
         The query object.
 
 :Examples:
@@ -2122,17 +2122,17 @@ def seasons(n=4, start=12):
 
 :Parameters:
 
-    n : int, optional
+    n: `int`, optional
         The number of seasons in the year. By default there are four
         seasons.
 
-    start : int, optional
+    start: `int`, optional
         The start month of the first season of the year. By default
         this is 12 (December).
 
 :Returns:
 
-    out : list of cf.Query
+    out: `list` of `cf.Query`
         The query objects.
 
 :Examples:
