@@ -157,16 +157,16 @@ Function  Description
 
 :Parameters:
 
-    duration : data-like
+    duration: data-like
         The length of the time duration.
 
-    units : str, optional
+    units: `str`, optional
         The units of the time duration. Only required if *duration* is
-        not a `cf.Data` object which contains the units. Must be one
-        a units string equivalent to calendar years, calendar months,
+        not a `cf.Data` object which contains the units. Must be a
+        units string equivalent to calendar years, calendar months,
         days, hours, minutes or seconds.
 
-    year, month, day, hour, minute, second : ints or None, optional 
+    year, month, day, hour, minute, second: `int` or `None`, optional 
         The default date-time elements for defining when a time
         interval based on this time duration (created with the
         `interval` method) begins or ends. See
@@ -180,7 +180,7 @@ Function  Description
 >>> t = cf.TimeDuration(30 , 'days')
 >>> t = cf.TimeDuration(1 , 'day', hour=6)
 
-'''
+        '''
         if units is not None:
             units = Units(units)
             self.duration = Data(abs(duration), units)
@@ -828,24 +828,24 @@ True if two time durations are equal.
 
 :Parameters:
 
-    other : 
+    other: 
         The object to compare for equality.
 
-    atol : float, optional
+    atol: `float`, optional
         The absolute tolerance for all numerical comparisons, By
         default the value returned by the `ATOL` function is used.
 
-    rtol : float, optional
+    rtol: `float`, optional
         The relative tolerance for all numerical comparisons, By
         default the value returned by the `RTOL` function is used.
 
-    traceback : bool, optional
+    traceback: `bool`, optional
         If True then print a traceback highlighting where the two
         instances differ.
 
 :Returns: 
 
-    out : bool
+    out: `bool`
         Whether or not the two instances are equal.
 
 :Examples:
@@ -904,24 +904,24 @@ True if two time durations are logically equivalent.
 
 :Parameters:
 
-    other : 
+    other: 
         The object to compare for equivalence.
 
-    atol : float, optional
+    atol: `float`, optional
         The absolute tolerance for all numerical comparisons, By
         default the value returned by the `ATOL` function is used.
 
-    rtol : float, optional
+    rtol: `float`, optional
         The relative tolerance for all numerical comparisons, By
         default the value returned by the `RTOL` function is used.
 
-    traceback : bool, optional
+    traceback: `bool`, optional
         If True then print a traceback highlighting where the two
         instances differ.
 
 :Returns: 
 
-    out : bool
+    out: `bool`
         Whether or not the two instances logically equivalent.
 
 :Examples:
@@ -1011,35 +1011,42 @@ The start (or end, if the *end* parameter is True) date-time of the
 time interval is determined by the `!year`, `!month`, `!day`, `!hour`,
 `!minute` and `!second` attributes.
 
+.. seealso:: `bounds`
+
 .. versionadded:: 1.0
 
+:Examples 1:
+
+>>> cf.TimeDuration(1, 'calendar_years').interval(1999)
+(<CF Datetime: 1999-01-01 00:00:00>, <CF Datetime: 2000-01-01 00:00:00>)
+
 :Parameters:
 
-    year, month, day, hour, minute, second : ints, optional
+    year, month, day, hour, minute, second: `int`, optional
         The date-time of the start (or end) of the time interval. If
         any parameter is unset then its value defaults to the
         attribute of the same name. The time interval calculation
         requires that all of the parameters have numerical values, so
-        if an unset parameter has a corresponding attribute default
-        which is `None` then an exception will be raised.
+        if an unset parameter has a corresponding attribute whose
+        value is `None` then an exception will be raised.
         
           *Example:*
             ``t.interval(year=1999, day=16)`` is equivalent to
             ``t.interval(1999, t.month, 16, t.hour, t.minute,
             t.second)``.
 
-    end : bool, optional
+    end: `bool`, optional
         If True then the date-time given by the *year*, *month*,
         *day*, *hour*, *minute* and *second* parameters defines the
         end of the time interval. By default it defines the start of
         the time interval.
 
-    calendar : str, optional
+    calendar: `str`, optional
         Define a CF calendar for the time interval. By default the
         Gregorian calendar is assumed. Ignored for time durations of
         calendar years or calendar months.
 
-    iso : string, optional
+    iso: `str`, optional
         Return the time interval as an ISO 8601 time interval string
         rather than the default of a tuple of date-time objects. Valid
         values are (with example outputs for the time interval "3
@@ -1055,13 +1062,13 @@ time interval is determined by the `!year`, `!month`, `!day`, `!hour`,
 
 :Returns:
 
-    out : 2-tuple of cf.Datetime or datetime.datetime; or str
+    out: 2-tuple of `cf.Datetime` or `datetime.datetime`; or `str`
         The date-times at each end of the time interval. The first
         date-time is always earlier than or equal to the second
         date-time. If *iso* has been set then an ISO 8601 time
         interval string is returned instead of a tuple.
 
-:Examples:
+:Examples 2:
 
 >>> cf.TimeDuration(1, 'calendar_months').interval(1999, 12)
 (<CF Datetime: 1999-12-01 00:00:00>, <CF Datetime: 2000-01-01 00:00:00>)
@@ -1243,16 +1250,82 @@ Create ISO 8601 time interval strings:
             return '%s/%s' % (self.iso, dt1)
     #--- End: def
 
-    def is_day_factor(self):
+    def bounds(self, year=None, month=1, day=1, hour=0, minute=0,
+               second=0, calendar=None, direction=True):
+        '''.. seealso:: `interval`
+
+.. versionadded:: 1.2.2
+
+:Examples 1:
+
+>>> 
+
+:Parameters:
+
+    direction: bool, optional       
+        If False then the bounds are decreasing. By default the bounds
+        are increasing. Note that ``t.bounds(*args, **kwargs,
+        direction=False)`` is equivalent to ``t.bounds(*args,
+        **kwargs)[::-1]``.
+        
+:Returns:
+
+        out: `cf.Datetime`, `cf.Datetime`
+        
+:Examples 2:
+
         '''
+        units = self.Units
+     
+        if units == _calendar_years:
+            dt0, dt1 = self.interval(year, self.month, self.day,
+                                     self.hour, self.minute,
+                                     self.second, calendar=calendar)
+        elif units == _calendar_months:
+            dt0, dt1 = self.interval(year, month, self.day, self.hour,
+                                     self.minute, self.second,
+                                     calendar=calendar)
+        elif units == _days:
+            dt0, dt1 = self.interval(year, month, day, self.hour,
+                                     self.minute, self.second,
+                                     calendar=calendar)
+        elif units == _hours:                                                
+            dt0, dt1 = self.interval(year, month, day, hour,
+                                     self.minute, self.second,
+                                     calendar=calendar)
+        elif units == _minutes:                                              
+            dt0, dt1 = self.interval(year, month, day, hour, minute,
+                                     self.second, calendar=calendar)
+        elif units == _seconds:                                              
+            dt0, dt1 = self.interval(year, month, day, hour, minute,
+                                     second, calendar=calendar)
+            
+        if dt0 > Datetime(year, month, day, hour, minute, second):
+            dt0, dt1 = self.interval(*dt0.timetuple()[:6], calendar=calendar,
+                                     end=True)              
 
-:Returns:	
+        if direction:
+            return  dt0, dt1
+        else:
+            return  dt1, dt0
+    #--- End: def
 
-    out : bool
+    def is_day_factor(self):
+        '''Return True if an integer multiple of the time duration is equal to
+one day.
 
 .. versionadded:: 1.0
 
-:Examples:
+:Examples 1:
+
+>>> cf.TimeDuration(0.5, 'days').is_day_factor()
+True
+
+:Returns:	
+
+    out: `bool`
+
+:Examples 2:
 
 >>> cf.TimeDuration(1, 'days').is_day_factor()
 True
@@ -1294,7 +1367,7 @@ False
 >>> cf.TimeDuration(1, 'calendar_years').is_day_factor()
 False
 
-'''
+        '''
         try:
             return not Data(1, 'day') % self.duration
         except ValueError:
@@ -1312,11 +1385,11 @@ def Y(duration=1, year=None, month=1, day=1, hour=0, minute=0, second=0):
 
 :Parameters:
 
-    duration : int, optional
+    duration: `int`, optional
         The number of calendar years in the time duration. Must be a
         non-negative integer.
 
-    year, month, day, hour, minute, second : ints, optional
+    year, month, day, hour, minute, second: `int`, optional
         The default date-time elements for defining the start and end
         of a time interval based on this time duration. See
         `cf.TimeDuration` and `cf.TimeDuration.interval` for details.
@@ -1327,7 +1400,7 @@ def Y(duration=1, year=None, month=1, day=1, hour=0, minute=0, second=0):
 
 :Returns:
 
-    out : cf.TimeDuration
+    out: `cf.TimeDuration`
         The new `cf.TimeDuration` object.
 
 :Examples:
@@ -1361,11 +1434,11 @@ object.
 
 :Parameters:
 
-    duration : int, optional
+    duration: `int`, optional
         The number of calendar months in the time duration. Must be a
         non-negative integer.
 
-    year, month, day, hour, minute, second : ints, optional
+    year, month, day, hour, minute, second: `int`, optional
         The default date-time elements for defining the start and end
         of a time interval based on this time duration. See
         `cf.TimeDuration` and `cf.TimeDuration.interval` for details.
@@ -1376,7 +1449,7 @@ object.
 
 :Returns:
 
-    out : cf.TimeDuration
+    out: `cf.TimeDuration`
         The new `cf.TimeDuration` object.
 
 :Examples:
@@ -1409,10 +1482,10 @@ def D(duration=1, year=None, month=1, day=1, hour=0, minute=0, second=0):
 
 :Parameters:
 
-    duration : number, optional
+    duration: number, optional
         The number of days in the time duration. Must be non-negative.
 
-    year, month, day, hour, minute, second : ints, optional
+    year, month, day, hour, minute, second: `int`, optional
         The default date-time elements for defining the start and end
         of a time interval based on this time duration. See
         `cf.TimeDuration` and `cf.TimeDuration.interval` for details.
@@ -1423,7 +1496,7 @@ def D(duration=1, year=None, month=1, day=1, hour=0, minute=0, second=0):
 
 :Returns:
 
-    out : cf.TimeDuration
+    out: `cf.TimeDuration`
         The new `cf.TimeDuration` object.
 
 :Examples:
@@ -1459,10 +1532,10 @@ def h(duration=1, year=None, month=1, day=1, hour=0, minute=0, second=0):
 
 :Parameters:
 
-    duration : number, optional
+    duration: number, optional
         The number of hours in the time duration. Must be non-negative.
 
-    year, month, day, hour, minute, second : ints, optional
+    year, month, day, hour, minute, second: `int`, optional
         The default date-time elements for defining the start and end
         of a time interval based on this time duration. See
         `cf.TimeDuration` and `cf.TimeDuration.interval` for details.
@@ -1473,7 +1546,7 @@ def h(duration=1, year=None, month=1, day=1, hour=0, minute=0, second=0):
 
 :Returns:
 
-    out : cf.TimeDuration
+    out: `cf.TimeDuration`
         The new `cf.TimeDuration` object.
 
 :Examples:
@@ -1509,10 +1582,10 @@ def m(duration=1, year=None, month=1, day=1, hour=0, minute=0, second=0):
 
 :Parameters:
 
-    duration : number, optional
+    duration: number, optional
         The number of hours in the time duration. Must be non-negative.
 
-    year, month, day, hour, minute, second : ints, optional
+    year, month, day, hour, minute, second: `int`, optional
         The default date-time elements for defining when a time
         interval based on this time duration begins or ends. See
         `cf.TimeDuration` and `cf.TimeDuration.interval` for details.
@@ -1523,7 +1596,7 @@ def m(duration=1, year=None, month=1, day=1, hour=0, minute=0, second=0):
 
 :Returns:
 
-    out : cf.TimeDuration
+    out: `cf.TimeDuration`
         The new `cf.TimeDuration` object.
 
 :Examples:
@@ -1559,11 +1632,11 @@ def s(duration=1, year=None, month=1, day=1, hour=0, minute=0, second=0):
 
 :Parameters:
 
-    duration : number, optional
+    duration: number, optional
         The number of hours in the time duration. Must be
         non-negative.
 
-    year, month, day, hour, minute, second : ints, optional
+    year, month, day, hour, minute, second: `int`, optional
         The default date-time elements for defining the start and end
         of a time interval based on this time duration. See
         `cf.TimeDuration` and `cf.TimeDuration.interval` for details.
@@ -1574,7 +1647,7 @@ def s(duration=1, year=None, month=1, day=1, hour=0, minute=0, second=0):
 
 :Returns:
 
-    out : cf.TimeDuration
+    out: `cf.TimeDuration`
         The new `cf.TimeDuration` object.
 
 :Examples:
