@@ -1,4 +1,3 @@
-
 import os
 import numpy
 import cf
@@ -199,56 +198,41 @@ class FieldTest(unittest.TestCase):
         f.ncvar = 'tas'
         all_kwargs = (
             {'inverse': False},
-            {'inverse': False, 'match': None},
-            {'inverse': False, 'match': {}},
-            {'inverse': False, 'match': []},
-            {'inverse': False, 'match': [None]},
-            {'inverse': False, 'match': [{}]},
-            {'inverse': False, 'match': [None, {}]},
-            {'inverse': False, 'match':  'eastward_wind'},
-            {'inverse': False, 'match':  'eastward_wind', 'exact': True},
-            {'inverse': False, 'match':  'eastward_'},
-            {'inverse': False, 'match':  'e.*_wind$'},
-            {'inverse': False, 'match':  'standard_name:eastward_wind'},
-            {'inverse': False, 'match':  'standard_name:eastward_wind', 'exact': True},
-            {'inverse': False, 'match':  'standard_name:eastward_'},
-            {'inverse': False, 'match': {'standard_name': 'eastward_wind'}},
-            {'inverse': False, 'match': {'standard_name': 'eastward_'}},
-            {'inverse': False, 'match': cf.eq('.*_wind', exact=False)},
-            {'inverse': False, 'match':  'long_name:qwerty'},
-            {'inverse': False, 'match':  'long_name:qwerty', 'exact': True},
-            {'inverse': False, 'match':  'long_name:qwe'},
-            {'inverse': False, 'match': {'long_name': 'qwerty'}},
-            {'inverse': False, 'match': {'long_name': 'qwe'}},
-            {'inverse': False, 'match': {'long_name': cf.eq('qwerty')}},
-            {'inverse': False, 'match': {'long_name': cf.eq('qwe', exact=False)}},
-            {'inverse': False, 'match': 'ncvar%tas'},
-            {'inverse': False, 'match': 'ncvar%tas', 'exact': True},
-            {'inverse': False, 'match': 'ncvar%ta'},
-            {'inverse': False, 'match': {None: 'ncvar%.*as$'}},
-            {'inverse': False, 'match': {None: 'ncvar%tas$'}},
-            {'inverse': False, 'match': {None: 'ncvar%tas'}},
-            {'inverse': False, 'match': {None: 'ncvar%ta'}},
-            #
-            {'inverse': False, 'ndim': 3},
-            {'inverse': False, 'match':  'eastward_wind', 'ndim': cf.wi(1, 3)},
-            {'inverse': False, 'match':  'BBB', 'ndim': cf.wi(1, 3), 'match_and': False},
-            {'inverse': False, 'match':  ['BBB', 'east'], 'ndim': cf.wi(1, 3), 'match_and': True},
-            #            {'inverse': False}, 
+            {'inverse': False, 'select': None},
+            {'inverse': False, 'select': {}},
+            {'inverse': False, 'select': []},
+            {'inverse': False, 'select': [None]},
+            {'inverse': False, 'select': [{}]},
+            {'inverse': False, 'select': [None, {}]},
+            {'inverse': False, 'select':  'eastward_wind'},
+            {'inverse': False, 'select':  'eastward_wind', 'exact': True},
+            {'inverse': False, 'select':  'eastward_'},
+            {'inverse': False, 'select':  'e.*_wind$'},
+            {'inverse': False, 'select':  'standard_name:eastward_wind'},
+            {'inverse': False, 'select':  'standard_name:eastward_wind', 'exact': True},
+            {'inverse': False, 'select':  'standard_name:eastward_'},
+            {'inverse': False, 'select': {'standard_name': 'eastward_wind'}},
+            {'inverse': False, 'select': {'standard_name': 'eastward_'}},
+            {'inverse': False, 'select': cf.eq('.*_wind', exact=False)},
+            {'inverse': False, 'select':  'long_name:qwerty'},
+            {'inverse': False, 'select':  'long_name:qwerty', 'exact': True},
+            {'inverse': False, 'select':  'long_name:qwe'},
+            {'inverse': False, 'select': {'long_name': 'qwerty'}},
+            {'inverse': False, 'select': {'long_name': 'qwe'}},
+            {'inverse': False, 'select': {'long_name': cf.eq('qwerty')}},
+            {'inverse': False, 'select': {'long_name': cf.eq('qwe', exact=False)}},
+            {'inverse': False, 'select': 'ncvar%tas'},
+            {'inverse': False, 'select': 'ncvar%tas', 'exact': True},
+            {'inverse': False, 'select': 'ncvar%ta'},
+            {'inverse': False, 'select': {None: 'ncvar%.*as$'}},
+            {'inverse': False, 'select': {None: 'ncvar%tas$'}},
+            {'inverse': False, 'select': {None: 'ncvar%tas'}},
+            {'inverse': False, 'select': {None: 'ncvar%ta'}},
+            #          
+            {'inverse': False, 'select':  'eastward_wind', 'ndim': cf.wi(1, 3)},
+            {'inverse': False, 'select':  'BBB', 'ndim': cf.wi(1, 3), 'match_and': False},
+            {'inverse': False, 'select':  ['BBB', 'east'], 'ndim': cf.wi(1, 3), 'match_and': True},
             {'inverse': False, 'ndim': cf.wi(1, 3)},
-#            {'inverse': False, 'match': 'eastward_wind'},
-#            {'inverse': False, 'match': {'long_name': 'qwerty'}},
-#            {'inverse': False, 'match': {'standard_name': 'east'}},
-#            {'inverse': False, 'match': 'east'},
-#            {'inverse': False, 'match': {'standard_name': 'east.*'}, 'exact': False},
-#            {'inverse': False, 'match': 'east.*', 'exact': False},
-#            {'inverse': False, 'match': cf.eq('east.*', exact=False)},
-#            {'inverse': False, 'match': {'standard_name': cf.eq('east.*', exact=False)}},
-#            {'inverse': False, 'match': {'standard_name': 'east', 'long_name': 'qwe'}},
-#            {'inverse': False, 'match': {'standard_name': 'east', 'long_name': 'qwe'}, 'match_and': False},
-#            {'inverse': False, 'match': {'standard_name': 'east', 'long_name': 'asd'}, 'match_and': False},
-#            #
-#            {'inverse': True, 'match': {'standard_name': 'east', 'long_name': 'asd'},},
         )
         for kwargs in all_kwargs:
             self.assertTrue(f.match(**kwargs), 
