@@ -51,12 +51,19 @@ class RegridTest(unittest.TestCase):
             f3 = cf.read(self.filename3)
             self.assertTrue(f3.equals(f1.regrids(f2), traceback=True),
                             'destination = global Field, CHUNKSIZE = %s' % chunksize)
+            self.assertTrue(f3.equals(f1.regrids(f2, method='conservative'), traceback=True),
+                            'destination = global Field, CHUNKSIZE = %s' % chunksize)
             dst = {'longitude': f2.dim('X'), 'latitude': f2.dim('Y')}
             self.assertTrue(f3.equals(f1.regrids(dst, dst_cyclic=True),
                                       traceback=True),
                             'destination = global dict, CHUNKSIZE = %s' % chunksize)
+            self.assertTrue(f3.equals(f1.regrids(dst, method='conservative',
+                                                 dst_cyclic=True), traceback=True),
+                            'destination = global dict, CHUNKSIZE = %s' % chunksize)
             f4 = cf.read(self.filename4)
             f5 = cf.read(self.filename5)
+            self.assertTrue(f4.equals(f1.regrids(f5), traceback=True),
+                            'destination = regional Field, CHUNKSIZE = %s' % chunksize)
             self.assertTrue(f4.equals(f1.regrids(f5, method='bilinear'), traceback=True),
                             'destination = regional Field, CHUNKSIZE = %s' % chunksize)
         #--- End: for
@@ -84,10 +91,16 @@ class RegridTest(unittest.TestCase):
             self.assertTrue(f6.equals(f4.regridc(f5, axes=('X', 'Y')),
                                       traceback=True),
                             'destination = global Field, CHUNKSIZE = %s' % chunksize)
+            self.assertTrue(f6.equals(f4.regridc(f5, axes=('X', 'Y'), method='conservative'),
+                                      traceback=True),
+                            'destination = global Field, CHUNKSIZE = %s' % chunksize)
             dst = {'X': f5.dim('X'), 'Y': f5.dim('Y')}
             self.assertTrue(f6.equals(f4.regridc(dst, axes=('X', 'Y')),
                                       traceback=True),
                             'destination = global dict, CHUNKSIZE = %s' % chunksize)
+            self.assertTrue(f6.equals(f4.regridc(dst, axes=('X', 'Y'), method='conservative'),
+                                      traceback=True),
+                            'destination = global dict, CHUNKSIZE = %s' % chunksize)
         #--- End: for
         cf.CHUNKSIZE(self.original_chunksize)
 
