@@ -28,6 +28,7 @@ class read_writeTest(unittest.TestCase):
     test_only = []
 #    test_only = ['NOTHING!!!!!']
 #    test_only = ['test_write_reference_datetime']
+#    test_only = ['test_write_HDF_chunks']
 
     def test_read_select(self):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
@@ -143,6 +144,20 @@ class read_writeTest(unittest.TestCase):
         cf.CHUNKSIZE(self.original_chunksize) 
     #--- End: def
 
+    def test_write_HDF_chunks(self):
+        if self.test_only and inspect.stack()[0][3] not in self.test_only:
+            return
+            
+        for chunksize in self.chunk_sizes:   
+            for fmt in ('NETCDF3_CLASSIC', 'NETCDF4'):
+                cf.CHUNKSIZE(chunksize) 
+                f = cf.read(self.filename)[0]
+                f.HDF_chunks({'T': 10000, 1: 3, 'grid_lat': 222, 45:45})
+                cf.write(f, tmpfile, fmt=fmt, HDF_chunksizes={'X': 6})
+        #--- End: for
+        cf.CHUNKSIZE(self.original_chunksize) 
+    #--- End: def
+
 #--- End: class
 
 if __name__ == "__main__":
